# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-12-02 08:45
from __future__ import unicode_literals

import django_intenum
import hearthstone.enums
from django.db import migrations, models


class Migration(migrations.Migration):

	initial = True

	dependencies = []

	operations = [
		migrations.CreateModel(
			name="Card",
			fields=[
				("card_id", models.CharField(max_length=50, primary_key=True, serialize=False)),
				("dbf_id", models.IntegerField(db_index=True, null=True, unique=True)),
				("name", models.CharField(max_length=50)),
				("description", models.TextField(blank=True)),
				("flavortext", models.TextField(blank=True)),
				("how_to_earn", models.TextField(blank=True)),
				("how_to_earn_golden", models.TextField(blank=True)),
				("artist", models.CharField(blank=True, max_length=255)),
				(
					"card_class", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.CardClass)
				),
				("card_set", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.CardSet)),
				("faction", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.Faction)),
				("race", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.Race)),
				("rarity", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.Rarity)),
				("type", django_intenum.IntEnumField(default=0, enum=hearthstone.enums.CardType)),
				("collectible", models.BooleanField(default=False)),
				("battlecry", models.BooleanField(default=False)),
				("divine_shield", models.BooleanField(default=False)),
				("deathrattle", models.BooleanField(default=False)),
				("elite", models.BooleanField(default=False)),
				("evil_glow", models.BooleanField(default=False)),
				("inspire", models.BooleanField(default=False)),
				("forgetful", models.BooleanField(default=False)),
				("one_turn_effect", models.BooleanField(default=False)),
				("poisonous", models.BooleanField(default=False)),
				("ritual", models.BooleanField(default=False)),
				("secret", models.BooleanField(default=False)),
				("taunt", models.BooleanField(default=False)),
				("topdeck", models.BooleanField(default=False)),
				("atk", models.IntegerField(default=0)),
				("health", models.IntegerField(default=0)),
				("durability", models.IntegerField(default=0)),
				("cost", models.IntegerField(default=0)),
				("windfury", models.IntegerField(default=0)),
				("spare_part", models.BooleanField(default=False)),
				("overload", models.IntegerField(default=0)),
				("spell_damage", models.IntegerField(default=0)),
				("craftable", models.BooleanField(default=False)),
			],
			options={
				"db_table": "card",
			},
		),
	]



# Generated by Django 4.0.4 on 2022-05-12 11:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cards', '0004_add_multi_class_group'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cardstring',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='cardtag',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



# Generated by Django 2.2.15 on 2020-08-03 09:49

from django.db import migrations
import django_intenum
import hearthstone.enums


class Migration(migrations.Migration):

    dependencies = [
        ('cards', '0003_auto_20190701_1420'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='multi_class_group',
            field=django_intenum.IntEnumField(default=0, enum=hearthstone.enums.MultiClassGroup),
        ),
    ]



# Generated by Django 4.2.1 on 2023-06-02 18:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cards', '0005_explicit_primary_keys'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='multiple_classes',
            field=models.IntegerField(default=0),
        ),
    ]



from django.contrib import admin

from .models import Adventure, Scenario, Wing


class ScenarioInline(admin.TabularInline):
	model = Scenario
	fields = ("name", "note_desc", "adventure", "wing", "mode")
	readonly_fields = fields
	extra = 0
	show_change_link = True


class WingInline(admin.TabularInline):
	model = Wing
	fields = (
		"name", "note_desc", "ownership_prereq_wing", "coming_soon_label"
	)
	readonly_fields = fields
	extra = 0
	show_change_link = True


@admin.register(Adventure)
class AdventureAdmin(admin.ModelAdmin):
	list_display = ("__str__", "note_desc")
	list_filter = ("leaving_soon", )
	search_fields = ("name", "note_desc")
	inlines = (WingInline, ScenarioInline, )


@admin.register(Wing)
class WingAdmin(admin.ModelAdmin):
	list_display = (
		"__str__", "adventure", "release", "required_event", "note_desc",
		"ownership_prereq_wing", "coming_soon_label", "requires_label"
	)
	list_filter = ("adventure", )
	search_fields = ("name", "note_desc")
	inlines = (ScenarioInline, )


@admin.register(Scenario)
class ScenarioAdmin(admin.ModelAdmin):
	list_display = (
		"__str__", "note_desc", "is_tutorial", "is_expert", "is_coop",
		"players", "adventure", "wing", "mode", "opponent_name",
	)
	list_filter = (
		"adventure", "players", "is_tutorial", "is_expert", "is_coop", "mode"
	)
	search_fields = ("name", "note_desc", "description", "opponent_name")



# Generated by Django 2.0.6 on 2019-07-01 19:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cards", "0002_auto_20180321_1313"),
    ]

    operations = [
        migrations.AlterField(
            model_name="card",
            name="name",
            field=models.CharField(max_length=64),
        ),
    ]
